
pycontrails
===========

*Python library for modeling aviation climate impacts.*


.. toctree::
   :titlesonly:
   :maxdepth: 1
   :caption: Getting Started

   install
   develop
   examples
   tutorials

.. toctree::
   :titlesonly:
   :maxdepth: 1
   :caption: Resources

   api
   literature
   contributing
   changelog

.. toctree::
   :titlesonly:
   :maxdepth: 1
   :caption: Links

   Github <https://github.com/contrailcirrus/pycontrails>
   Contrails Map <https://map.contrails.org>
   Contrails API <https://api.contrails.org>
